@@ -2,7 +2,7 @@ context("Compute full analysis")
 
 test_that("creates a list with the proper named lists", {
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
   data <- suppressMessages(suppressWarnings(
     compute_full_analysis(station_number = "08NM116", start_year = 1980, end_year = 1985)))
   expect_true("list" %in% class(data) &
@@ -12,7 +12,7 @@ test_that("creates a list with the proper named lists", {
 
 test_that("creates a list with proper analyses", {
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
   data <- suppressMessages(suppressWarnings(
     compute_full_analysis(station_number = "08NM116", start_year = 1980, end_year = 1985,
                                                  analyses = c(1:2,7))))
